Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(515)

Unified Diff: chrome/browser/profiles/profile_manager.h

Issue 1794353003: Refactor ProfileInfoCache in c/b/profiles (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Replaced LOG(WARNING) by UMA histograms Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile_manager.h
diff --git a/chrome/browser/profiles/profile_manager.h b/chrome/browser/profiles/profile_manager.h
index a37337a12d82479c4c7768a3fbb98973f05e1cdc..ed8c787a0f7013e2dfebe428f6144f205532acfe 100644
--- a/chrome/browser/profiles/profile_manager.h
+++ b/chrome/browser/profiles/profile_manager.h
@@ -28,6 +28,7 @@
#include "content/public/browser/notification_registrar.h"
class NewProfileLauncher;
+class ProfileAttributesStorage;
class ProfileInfoCache;
class ProfileManager : public base::NonThreadSafe,
@@ -208,11 +209,11 @@ class ProfileManager : public base::NonThreadSafe,
// Register and add testing profile to the ProfileManager. Use ONLY in tests.
// This allows the creation of Profiles outside of the standard creation path
// for testing. If |addToCache|, adds to ProfileInfoCache as well.
// If |start_deferred_task_runners|, starts the deferred task runners.
// Use ONLY in tests.
void RegisterTestingProfile(Profile* profile,
- bool addToCache,
+ bool addToStorage,
bool start_deferred_task_runners);
const base::FilePath& user_data_dir() const { return user_data_dir_; }
@@ -308,8 +309,9 @@ class ProfileManager : public base::NonThreadSafe,
// should be used carefully.
Profile* GetProfileByPathInternal(const base::FilePath& path) const;
- // Adds |profile| to the profile info cache if it hasn't been added yet.
- void AddProfileToCache(Profile* profile);
+ // Adds |profile| to the profile attributes storage if it hasn't been added
+ // yet.
+ void AddProfileToStorage(Profile* profile);
// Apply settings for profiles created by the system rather than users: The
// (desktop) Guest User profile and (desktop) System Profile.
@@ -208,11 +209,11 @@ class ProfileManager : public base::NonThreadSafe,
// Register and add testing profile to the ProfileManager. Use ONLY in tests.
// This allows the creation of Profiles outside of the standard creation path
- // for testing. If |addToCache|, adds to ProfileInfoCache as well.
+ // for testing. If |addToStorage|, adds to ProfileAttributesStorage as well.
// If |start_deferred_task_runners|, starts the deferred task runners.
// Use ONLY in tests.

Powered by Google App Engine
This is Rietveld 408576698